@@ -21,6 +21,9 @@ from typing import Callable
 
 
 class PositionAHRS:
+    """
+    Position AHRS
+    """
     def __init__(self):
         self.beta = 0
         self.pi = 0
@@ -111,6 +114,9 @@ class PositionAHRS:
 
 
 class ConcurrentHandler:
+    """
+    Defined Concurrent Process Handler
+    """
     def __init__(self, max_workers: int, call_back: Callable):
         self.__threadPool = ThreadPoolExecutor(max_workers=max_workers, thread_name_prefix="sencyber")
         self.__call_back = call_back
@@ -190,6 +196,9 @@ class AutoQueue:
 
 
 class SencyberLogger:
+    """
+    Defines a Logger using default python logger and send the logs to specific server
+    """
     def __init__(self, receiver_address='0.0.0.0', receiver_port=10080, title='default', auto_interval=1200):
         self.receiver_address = receiver_address
         self.receiver_port = receiver_port
@@ -224,6 +233,9 @@ class SencyberLogger:
             state = self.__send_logs()
             if state == 0:
                 break
+            else:
+                logging.debug(f"Retry Upload...")
+                time.sleep(5)
 
     def __send_logs(self):
         client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -256,20 +268,26 @@ class SencyberLogger:
                 client.send(s_header)
                 client.send(header_bytes)
                 client.send(data)
+                client.close()
             else:
                 logging.error(f"{self.receiver_address}:{self.receiver_port} is not a proper log server.")
+                client.close()
                 return 1
         except ConnectionResetError:
             logging.error(f"Connection Reset By Peer.")
+            print(f"Connection Reset By Peer.")
+            client.close()
             return 1
         except TimeoutError:
             logging.error(f"Connection Time Out.")
+            print(f"Connection Time Out.")
+            client.close()
             return 1
         except Exception:
             logging.error(f"Unhandled Exception Occurred: {traceback.format_exc()}")
-            return 1
-        finally:
+            print(f"Unhandled Exception Occurred: {traceback.format_exc()}")
             client.close()
+            return 1
         return 0
 
     def __backUp(self):
@@ -293,6 +311,9 @@ class SencyberLogger:
 
 
 class SencyberLoggerReceiver:
+    """
+    Defines a Server For receiving the logs
+    """
     def __init__(self, bind_address="0.0.0.0", bind_port=10080, path="./"):
         LOG_FORMAT = "%(asctime)s [%(levelname)s]: %(message)s @ [%(module)s-%(lineno)s]"
         logging.basicConfig(
@@ -318,8 +339,6 @@ class SencyberLoggerReceiver:
         try:
             data = conn.recv(6)
             if data == b"\x55\xAASTT\xED":
-                self.__lock.acquire()
-                self.__lock.release()
                 conn.send(b"\x55\xAARCV\xED")
 
                 s_header = conn.recv(4)
@@ -358,12 +377,18 @@ class SencyberLoggerReceiver:
             logging.error("Exception!!")
             logging.error(traceback.format_exc())
             logging.error("=" * 50)
-
+        logging.info(f"[{address}] Recv Completed...")
         conn.close()
         return
 
 
 def a_to_hex(val: int) -> str:
+    """
+
+    :param val: 0 ~ 15
+    :return:
+    """
+
     if val < 10:
         return str(val)
     elif val == 10:
@@ -381,6 +406,11 @@ def a_to_hex(val: int) -> str:
 
 
 def hex_to_str(payload: bytes) -> str:
+    """
+    Make the payload into human readable string
+    :param payload: bytes
+    :return: string
+    """
     raw = ""
     for d in payload:
         ten = a_to_hex(d // 16)
@@ -390,3 +420,31 @@ def hex_to_str(payload: bytes) -> str:
     return raw
 
 
+def angle_changing(acc: tuple, alpha: float, beta: float, theta: float) -> tuple:
+    """
+    Adjust acc by euler angles (radians).
+    :param acc: acc_x, acc_y, acc_z
+    :param alpha:
+    :param beta:
+    :param theta:
+    :return: adjusted acc
+    """
+    # theta -> beta -> alpha
+
+    x, y, z = acc
+
+    z1 = z
+    x1 = x * math.cos(theta) - y * math.sin(theta)
+    y1 = x * math.sin(theta) - y * math.cos(theta)
+
+    z2 = z1 * math.cos(beta) - x1 * math.sin(beta)
+    x2 = x1 * math.cos(beta) + z1 * math.sin(beta)
+    y2 = y1
+
+    z3 = z2 * math.cos(alpha) + y2 * math.sin(alpha)
+    y3 = y2 * math.cos(alpha) - z2 * math.sin(alpha)
+    x3 = x2
+
+    y3 = -y3
+
+    return x3, y3, z3
